from setuptools import setup

setup(name='braga',
      version='0.1',
      description='Toy Entity-Component system',
      url='http://github.com/astrosilverio/braga',
      author='astrosilverio',
      author_email='astrosilverio@gmail.com',
      license='MIT',
      packages=['braga'],
      zip_safe=False)



class Entity(object):

    __slots__ = ('_uuid', 'components')

    def __init__(self, uuid):
        self._uuid = uuid
        self.components = set()

    @property
    def uuid(self):
        return self._uuid

    def __repr__(self):
        return "{0}({1}) - {2}".format(type(self).__name__, self._uuid, self.components)

    def __getattr__(self, name):
        for component in self.components:
            try:
                attr = getattr(component, name)
            except AttributeError:
                pass
            else:
                return attr
        raise AttributeError


class Component(object):
    def __repr__(self):
        return type(self).__name__
